@@ -36,15 +36,20 @@ from deeppavlov.core.common.log import log_config
 from deeppavlov.core.common.paths import get_settings_path
 from deeppavlov.core.data.utils import check_nested_dict_keys, jsonify_data
 from deeppavlov.utils.connector import DialogLogger
+from deeppavlov.utils.server.metrics import metrics, PrometheusMiddleware
 
 SERVER_CONFIG_PATH = get_settings_path() / 'server_config.json'
 SSLConfig = namedtuple('SSLConfig', ['version', 'keyfile', 'certfile'])
 
-
 log = getLogger(__name__)
 dialog_logger = DialogLogger(logger_name='rest_api')
 
-app = FastAPI(__file__)
+app = FastAPI()
+
+app.add_middleware(
+    PrometheusMiddleware,
+    ignore_paths=('/', '/metrics', '/api', '/probe', '/docs', '/openapi.json')
+)
 
 app.add_middleware(
     CORSMiddleware,
@@ -54,6 +59,8 @@ app.add_middleware(
     allow_headers=['*']
 )
 
+app.add_route("/metrics", metrics)
+
 
 def get_server_params(model_config: Union[str, Path]) -> Dict:
     server_config = read_json(SERVER_CONFIG_PATH)
